@@ -1,4 +1,5 @@
 #!/usr/bin/python3
+#-*- coding: utf-8 -*-
 #
 # (c) MMXXII UNKNOWN
 #
@@ -530,6 +531,9 @@ def main():
         else:
           lfiltered = 1
           cury=1
+          # when filter is apllied then move to the first table
+          tabf=0
+          curtabsf=0
         act = ""
         screen.move(0,0)
         screen.clrtoeol()
