@@ -12,16 +12,18 @@ cfg_dbf = ":memory:"
 
 def prep_cfg_storage():
   ccon = sqlite3.connect(cfg_dbf)
-  cfg,cfgcol = cfg_qry2dict(
+  ccon,cfg,cfgcol = cfg_qry2dict(
+    ccon,
     "create table if not exists cfg (db text, tab text, key text, value text, primary key(db,tab,key))",
-    (),cfg_dbf,ccon)
+    (),cfg_dbf)
   return(ccon)
 
 def cfg_get_value(ccon,params):
   # Restore Current Table settings BEGIN
-  cfg,cfgcol = cfg_qry2dict(
+  ccon,cfg,cfgcol = cfg_qry2dict(
+    ccon,
     "select * from cfg where tab = ? and key = ?",
-     params,cfg_dbf,ccon
+    params,cfg_dbf
   )
   if "value" in cfg:
     return(cfg["value"][0])
@@ -30,15 +32,16 @@ def cfg_get_value(ccon,params):
 
 def cfg_set_value(ccon,params):
   # Store Current Table Settings
-  cfg,cfgcol = cfg_qry2dict(
+  ccon,cfg,cfgcol = cfg_qry2dict(
+    ccon,
     """insert into cfg values (?,?,?,?)
        on conflict (db,tab,key)
        do update set value = ?""",
-       params,cfg_dbf,ccon
+       params,cfg_dbf
   )    
 
 def cfg_get_all(ccon):
-  cfg,cfgcol = cfg_qry2dict(
+  ccon,cfg,cfgcol = cfg_qry2dict(
     "select * from cfg",
      (),cfg_dbf,ccon
   )
